@@ -8,18 +8,6 @@ from LivestockCV.core import params
 
 
 def invert(gray_img):
-    """Inverts grayscale images.
-
-    Inputs:
-    gray_img     = Grayscale image data
-
-    Returns:
-    img_inv = inverted image
-
-    :param gray_img: numpy.ndarray
-    :return img_inv: numpy.ndarray
-    """
-
     params.device += 1
     img_inv = cv2.bitwise_not(gray_img)
     if params.debug == 'print':
